aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil/filesystem.c
diff options
context:
space:
mode:
authorBalint Reczey <balint@balintreczey.hu>2014-05-29 00:32:20 +0700
committerAlexis La Goutte <alexis.lagoutte@gmail.com>2014-05-30 12:48:08 +0000
commit7bf49b31ace52a0cfbc33ffe29afce5c0befb685 (patch)
tree8e4111fe450c051d8cc85817954e4dc628540204 /wsutil/filesystem.c
parentaff380770a8b99c2ac417736cd9f1c049d1da44e (diff)
Set PLUGIN_INSTALL_DIR properly for wireshark.pc
Change-Id: I64c04095ce780ce2cc44a54a68695506d27e5747 Reviewed-on: https://code.wireshark.org/review/1861 Reviewed-by: Alexis La Goutte <alexis.lagoutte@gmail.com>
Diffstat (limited to 'wsutil/filesystem.c')
-rw-r--r--wsutil/filesystem.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/wsutil/filesystem.c b/wsutil/filesystem.c
index 1a316e2379..e98a291640 100644
--- a/wsutil/filesystem.c
+++ b/wsutil/filesystem.c
@@ -1069,7 +1069,7 @@ get_wspython_dir(void)
*
* On Windows, we use the "plugin" subdirectory of the datafile directory.
*
* On UN*X, we use the PLUGIN_DIR value supplied by the configure
* script, unless we think we're being run from the build directory,
* in which case we use the "plugin" subdirectory of the datafile directory.
*
@@ -1153,7 +1153,7 @@ init_plugin_dir(void)
}
#endif
else {
- plugin_dir = PLUGIN_DIR;
+ plugin_dir = PLUGIN_INSTALL_DIR;
}
}
#endif
@@ -1069,7 +1069,7 @@ get_wspython_dir(void)
* On Windows, we use the "plugin" subdirectory of the datafile directory.
*
- * On UN*X, we use the PLUGIN_DIR value supplied by the configure
+ * On UN*X, we use the PLUGIN_INSTALL_DIR value supplied by the configure
* script, unless we think we're being run from the build directory,
* in which case we use the "plugin" subdirectory of the datafile directory.